==> haskell-storable-complex-0.2.3.0-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-complex
version: 0.2.3.0
id: storable-complex-0.2.3.0-3gXsseRaSO93gtSnr3ED4y
key: storable-complex-0.2.3.0-3gXsseRaSO93gtSnr3ED4y
license: BSD-3-Clause
maintainer: Carter Schonwald <carter.schonwald@gmail.com>
author: Jed Brown <jed@59A2.org>
homepage: https://github.com/cartazio/storable-complex
synopsis: Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.
    .
    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.
category: Data
abi: 50cb94973e56701c2c06ca212432309e
exposed: True
exposed-modules:
    Foreign.Storable.Complex
import-dirs: /usr/lib/ghc-8.6.5/site-local/storable-complex-0.2.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/storable-complex-0.2.3.0
hs-libraries: HSstorable-complex-0.2.3.0-3gXsseRaSO93gtSnr3ED4y
depends:
    base-4.12.0.0 base-orphans-0.8.1-1eiH9qVb6AAEHB9dzgavFy
haddock-interfaces: /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock
haddock-html: /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-complex-0.2.3.0-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-complex
version: 0.2.3.0
id: storable-complex-0.2.3.0-IqTssBZ2G90J9kRbLSMmF1
key: storable-complex-0.2.3.0-IqTssBZ2G90J9kRbLSMmF1
license: BSD-3-Clause
maintainer: Carter Schonwald <carter.schonwald@gmail.com>
author: Jed Brown <jed@59A2.org>
homepage: https://github.com/cartazio/storable-complex
synopsis: Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.
    .
    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.
category: Data
abi: bd673598ae8d3ca43d14aba1b187ba55
exposed: True
exposed-modules:
    Foreign.Storable.Complex
import-dirs: /usr/lib/ghc-8.6.5/site-local/storable-complex-0.2.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/storable-complex-0.2.3.0
hs-libraries: HSstorable-complex-0.2.3.0-IqTssBZ2G90J9kRbLSMmF1
depends:
    base-4.12.0.0 base-orphans-0.8.1-HeyTAcy4PKhDcGhjvJwDzq
haddock-interfaces: /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock
haddock-html: /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
